summaryrefslogtreecommitdiffstats
path: root/kdejava/koala/org/kde/koala/KPluginSelector.java
diff options
context:
space:
mode:
Diffstat (limited to 'kdejava/koala/org/kde/koala/KPluginSelector.java')
-rw-r--r--kdejava/koala/org/kde/koala/KPluginSelector.java14
1 files changed, 7 insertions, 7 deletions
diff --git a/kdejava/koala/org/kde/koala/KPluginSelector.java b/kdejava/koala/org/kde/koala/KPluginSelector.java
index f40c903e..62cf53a2 100644
--- a/kdejava/koala/org/kde/koala/KPluginSelector.java
+++ b/kdejava/koala/org/kde/koala/KPluginSelector.java
@@ -63,17 +63,17 @@ public class KPluginSelector extends TQWidget {
parameter to select only those KParts plugins
with the Category key == <code>category.</code> If <code>category</code> is not set the Category key is ignored
and all plugins are shown.
- @param config The KConfig object that holds the state of the
+ @param config The TDEConfig object that holds the state of the
plugins being enabled or not. By default it should
be instance.config(). It is recommended to
- always pass a KConfig object if you use
+ always pass a TDEConfig object if you use
KSettings.PluginPage since you never know from where the
page will be called (think global config app).
For example KViewCanvas passes KSimpleConfig(
"kviewcanvas" ).
@short Add a list of KParts plugins
*/
- public native void addPlugins(String instanceName, String catname, String category, KConfig config);
+ public native void addPlugins(String instanceName, String catname, String category, TDEConfig config);
public native void addPlugins(String instanceName, String catname, String category);
public native void addPlugins(String instanceName, String catname);
public native void addPlugins(String instanceName);
@@ -82,7 +82,7 @@ public class KPluginSelector extends TQWidget {
If not set explicitely, <code>config</code> is set to instance.config().
@short Add a list of KParts plugins.
*/
- public native void addPlugins(TDEInstanceInterface instance, String catname, String category, KConfig config);
+ public native void addPlugins(TDEInstanceInterface instance, String catname, String category, TDEConfig config);
public native void addPlugins(TDEInstanceInterface instance, String catname, String category);
public native void addPlugins(TDEInstanceInterface instance, String catname);
public native void addPlugins(TDEInstanceInterface instance);
@@ -100,17 +100,17 @@ public class KPluginSelector extends TQWidget {
parameter to select only those KParts plugins
with the Category key == <code>category.</code> If <code>category</code> is not set the Category key is ignored
and all plugins are shown.
- @param config The KConfig object that holds the state of the
+ @param config The TDEConfig object that holds the state of the
plugins being enabled or not. By default it will
use TDEGlobal.config(). It is recommended to
- always pass a KConfig object if you use
+ always pass a TDEConfig object if you use
KSettings.PluginPage since you never know from where the
page will be called (think global config app).
For example KViewCanvas passes KSimpleConfig(
"kviewcanvas" ).
@short Add a list of non-KParts plugins
*/
// void addPlugins(const TQValueList<KPluginInfo*>& arg1,const TQString& arg2,const TQString& arg3,KConfig* arg4); >>>> NOT CONVERTED
// void addPlugins(const TQValueList<KPluginInfo*>& arg1,const TQString& arg2,const TQString& arg3); >>>> NOT CONVERTED
// void addPlugins(const TQValueList<KPluginInfo*>& arg1,const TQString& arg2); >>>> NOT CONVERTED
// void addPlugins(const TQValueList<KPluginInfo*>& arg1); >>>> NOT CONVERTED
@@ -100,17 +100,17 @@ public class KPluginSelector extends TQWidget {
*/
- // void addPlugins(const TQValueList<KPluginInfo*>& arg1,const TQString& arg2,const TQString& arg3,KConfig* arg4); >>>> NOT CONVERTED
+ // void addPlugins(const TQValueList<KPluginInfo*>& arg1,const TQString& arg2,const TQString& arg3,TDEConfig* arg4); >>>> NOT CONVERTED
// void addPlugins(const TQValueList<KPluginInfo*>& arg1,const TQString& arg2,const TQString& arg3); >>>> NOT CONVERTED
// void addPlugins(const TQValueList<KPluginInfo*>& arg1,const TQString& arg2); >>>> NOT CONVERTED